---
name: Discussion
about: Start a discussion
title: ''
labels: ''
assignees: ''

---

**Start a discussion about anything you would like**
Discussions can be used to ask questions, discuss new ideas, or anything else.
